@@ -35,7 +35,7 @@ int ret;
 		close(1);
 		dup(p[1]);
 		close(p[0]);
-		for ( id = 3 ; id <= OPEN_MAX ; id ++ )
+		for ( id = 3 ; id <= sys_param.max_fd ; id ++ )
 			close(id);
 		system("uname -X | egrep NumCPU");
 		exit(0);
