@@ -119,8 +119,8 @@ int mode;
 	mode = fcntl(d,F_GETFL);
 	if ( mode < 0 )
 		return 0;
-	mode &= ~3;
-	fcntl(d,F_SETFL,mode);
+	mode &= 3;
+//	fcntl(d,F_SETFL,mode);
 	ret = d_alloc(sizeof(S_FILE));
 	ret->h.tbl = tbl;
 	ret->h.thread = 0;
@@ -146,8 +146,8 @@ int mode;
 	mode = fcntl(d,F_GETFL);
 	if ( mode < 0 )
 		return 0;
-	mode &= ~3;
-	fcntl(d,F_SETFL,mode);
+	mode &= 3;
+//	fcntl(d,F_SETFL,mode);
 	ret = d_alloc(sizeof(S_FILE));
 	ret->h.tbl = tbl;
 	ret->h.thread = 0;
