@@ -27,7 +27,7 @@
 typedef struct s_file {
 	S_HEADER	h;
 	HANDLE hfile;
-	FILE * std_fd;
+/*	FILE * std_fd; */
 } S_FILE;
 
 typedef struct s_accept {
@@ -44,7 +44,7 @@ typedef struct s_terminal {
 
 typedef struct s_socket {
 	S_HEADER	h;
-	int		fid;
+	SOCKET		sock;
 } S_SOCKET;
 
 typedef struct pipe_read_buf {
@@ -74,23 +74,59 @@ typedef union stream {
 	S_ACCEPT	accept;
 	S_TERMINAL	terminal;
 	S_STRING	str;
-	S_SOCKET	_socket;
+	S_SOCKET	socket;
 	S_CHAIN		chain;
 	S_FPIPE		fpipe;
 	S_XLoHTTP	xoh;
 } STREAM;
 
+/*
 typedef struct proc_send {
 	char	msg[32];
-	int		fid[2];
+	HANDLE	fid[3];
 } PROC_SEND;
 
 typedef struct proc_recv {
 	char *	ptr;
-	int	fidp;
+	HANDLE	fidp;
 	S_TABLE *	tbl;
 } PROC_RECV;
+*/
 
+/* structures about pass data via process */
+typedef struct proc_send_header{
+	int size; /* total size of chunk */
+	char type; /* type of send data */
+}PROC_SEND_HEADER;
+
+typedef struct proc_send_chunk{
+	PROC_SEND_HEADER header;
+}PROC_SEND_CHUNK;
+
+/* the message written to the stream, after receive the stream by child process.*/
+typedef struct proc_send_message{
+	PROC_SEND_HEADER header;
+	char message_on_receive[1];
+}PROC_SEND_MESSAGE;
+
+typedef struct proc_send_file{
+	PROC_SEND_HEADER header;
+	HANDLE hfile;
+	int open_mode;
+}PROC_SEND_FILE;
+
+typedef struct proc_send_socket{
+	PROC_SEND_HEADER header;
+	SOCKET sock;
+	int open_mode;
+}PROC_SEND_SOCKET;
+
+typedef struct proc_send_fpipe{
+	PROC_SEND_HEADER header;
+	int fid_read;
+	int fid_write;
+	int open_mode;
+}PROC_SEND_FPIPE;
 
 
 extern STREAM ** recv_streams;
@@ -102,4 +138,9 @@ extern S_TABLE s_socket_table;
 //#define s_socket_table s_file_table
 #define s_pipe_table s_file_table
 
+
+STREAM *s_open_file_descripter(HANDLE hfile, int open_mode, BOOL do_lock);
+void remove_command_line_ampersand(char *command_line);
+void meke_proc_send_event_name(char *ret_event_name, const char *map_name);
+
 #endif
