@@ -21,7 +21,9 @@ int
 main(int argc,char ** argv)
 {
 	char * msg;
-	
+
+	printf("%s is executed. \n", argv[0]);
+
 	check_endian();
 	init_task(INI_DONTWAITCHI);
 	init_tick();
@@ -30,13 +32,23 @@ main(int argc,char ** argv)
 	init_stream();
 	init_utils();
 	init_netutils();
-	
+	init_resolve();
+
 	if ( argc > 1 && argv[1][0] == '+' ) {
+		int i;
+		/*
 		msg = argv[1];
 		argv[1] = argv[0];
 		argv ++;
 		argc --;
 		proc_recv_stream(msg);
+		*/
+		proc_recv_stream(&(argv[1][1]));
+		argv +=2;
+		argc -=2;
+		for(i=0;i<argc;++i){
+			printf("arg%d=%s\n", i, argv[i]);
+		}
 	}
 	
 	return _main(argc,argv);
