@@ -43,6 +43,7 @@ char * msg;
 	init_msequence();
 	check_endian();
 	init_tick();
+	init_d_alloc();
 	init_longchar();
 	init_stream();
 	init_utils();
@@ -50,12 +51,17 @@ char * msg;
 	init_resolve();
 
 	if ( argv[1][0] == '+' ) {
+		/*
 		msg = argv[1];
 		argv[1] = argv[0];
 		argv ++;
 		argc --;
 		proc_recv_stream(msg);
+		*/
+		proc_recv_stream(&(argv[1][1]));
+		argv +=2;
+		argc -=2;
 	}
 
 	return _main(argc,argv);
-}
\ No newline at end of file
+}
