@@ -42,13 +42,6 @@ void new_v_loop(VDISPLAY * d)
 	while( GetMessage(&msg, NULL, 0, 0) ) 
 	{
 		vd = d;
-		if( msg.message == MYMSG_INVRECT )
-		{
-			InvalidateRect(ghWnd,NULL,FALSE);
-			PostMessage(ghWnd, WM_PAINT, 0, 0);
-			continue;
-		}
-
 		TranslateMessage( &msg );
 		DispatchMessage( &msg );
 	}
@@ -87,12 +80,21 @@ LRESULT CALLBACK WndProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			hdc = BeginPaint(hWnd, &ps);
 			if(IsFirstTime)
 			{
-				// Sleep(2000);
 				win = _get_vwin(vd,hWnd);
 				_redraw(win,ps.rcPaint.left,ps.rcPaint.top,ps.rcPaint.right-ps.rcPaint.left,ps.rcPaint.bottom-ps.rcPaint.top);
 				IsFirstTime = 0;
 			}
-			BitBlt(hdc, ps.rcPaint.left, ps.rcPaint.top, ps.rcPaint.right, ps.rcPaint.bottom, ghBufferDC, ps.rcPaint.left, ps.rcPaint.top, SRCCOPY);
+			
+			BitBlt(hdc, 
+				ps.rcPaint.left, 
+				ps.rcPaint.top,
+				ps.rcPaint.right,
+				ps.rcPaint.bottom, 
+				ghBufferDC,
+				ps.rcPaint.left,
+				ps.rcPaint.top, 
+				SRCCOPY);
+			
 			EndPaint( hWnd, &ps );
 			break;
 
@@ -106,11 +108,7 @@ LRESULT CALLBACK WndProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			win = _get_vwin(vd,hWnd);
 			if (win) 
 			{
-				hdc = GetDC(hWnd);
-				win->gc = hdc;
 				_button(win,VES_BUTTON_PRESS,1/*time*/,xPos,yPos);
-				win->gc = NULL;
-				ReleaseDC(hWnd,hdc);
 			}
 			break;
 
@@ -130,7 +128,7 @@ LRESULT CALLBACK WndProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			}
 			IsMouseMove = 0;
 			break;
-
+			
 		case WM_MOUSEMOVE:
 			IsMouseMove = 1;
 			xPos = LOWORD(lParam);
@@ -140,7 +138,6 @@ LRESULT CALLBACK WndProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			{
 				VOBJECT *obj;
 				hdc = GetDC(hWnd);
-				win->gc = hdc;
 				_button(win,VES_BUTTON_MOTION,1,xPos,yPos);
 				GetClientRect(hWnd,&rt);
 				for ( obj = win->obj_list ; obj ; obj = obj->header.next )
@@ -148,10 +145,9 @@ LRESULT CALLBACK WndProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 					if(obj->header.type == 2)
 						(*obj->header.handler)(obj,VE_REDRAW,rt.left,rt.top,rt.right-rt.left,rt.bottom-rt.top);
 				}
-				BitBlt(hdc,rt.left,rt.top,rt.right,rt.bottom, ghBufferDC,rt.left,rt.top, SRCCOPY);
-				win->gc = NULL;	
 				ReleaseDC(hWnd,hdc);
-			}	
+				InvalidateRect(hWnd, NULL, FALSE);
+			}
 
 			break;
 
@@ -168,7 +164,7 @@ LRESULT CALLBACK WndProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			{
 				hdc = GetDC(hWnd);
 				ghBufferDC = CreateCompatibleDC(hdc);
-				ghBufferImage = CreateCompatibleBitmap(GetDC(hWnd),GetSystemMetrics(SM_CXSCREEN),GetSystemMetrics(SM_CYSCREEN));
+				ghBufferImage = CreateCompatibleBitmap(hdc,GetSystemMetrics(SM_CXSCREEN),GetSystemMetrics(SM_CYSCREEN));
 				ghBufferImageOld = SelectObject(ghBufferDC,ghBufferImage);
 
 				ReleaseDC(hWnd,hdc);
