@@ -28,21 +28,21 @@ SEM pfc_lock_lock;
 int
 lock_pfc(PFC * p)
 {
-XL_SEXP * ret;
+CALL_LOCK_DESCRIPTER ret;
 	gc_push(0,0,"lock_pfc"); 
-	ret = connect_lock(0,l_string(std_cm,p->filename),"write");
-	if ( get_type(ret) != XLT_INTEGER ) {
+	ret = call_lock(l_string(std_cm,p->filename),CLT_WRITE_LOCK);
+	if ( cl_error_check(ret) ) {
 
-		p->lock_id = 0;
+		p->lock_id = cl_invalid();
 		gc_pop(0,0);
 		return -1;
 	}
 
 
 	lock_task(pfc_lock_lock);
-	if ( p->lock_id )
+	if ( cl_error_check(p->lock_id) == 0 )
 		er_panic("lock_pfc(1)");
-	p->lock_id = ret->integer.data;
+	p->lock_id = ret;
 	unlock_task(pfc_lock_lock,"lock_pfc");
 
 	gc_pop(0,0);
@@ -53,19 +53,19 @@ XL_SEXP * ret;
 void
 unlock_pfc(PFC * p)
 {
-int id;
+CALL_LOCK_DESCRIPTER id;
 char * ptr;
 int i;
 
 	lock_task(pfc_lock_lock);
-	if ( p->lock_id == 0 )
+	if ( cl_error_check(p->lock_id) )
 		er_panic("unlock_pfc(1)");
 	gc_push(0,0,"unlock_pfc");
 
 	id = p->lock_id;
-	p->lock_id = 0;
+	p->lock_id = cl_invalid();
 	unlock_task(pfc_lock_lock,"unlock_pfc");
 
-	connect_unlock(0,id,l_string(std_cm,p->filename));
+	call_unlock(id);
 	gc_pop(0,0);
 }
