@@ -1117,6 +1117,8 @@ L_CHAR * tmp;
 	b_target = get_body(n->target);
 	if ( b_start && b_target && l_strcmp(b_start,b_target) ) {
 ss_printf("RESOLVE_ERROR %ls %ls\n",n->start,n->target);
+ss_printf("RESOLVE_ERROR-DATA\n");
+ss_printf("RR %ls %ls\n",b_start,b_target);
 		n->flags |= RQT_ROUTE_ERR;
 		purge_rs_cache(n->start);
 		purge_rs_cache(n->target);
