@@ -60,7 +60,7 @@ e2d_p_move(
 {
 VPOINT * ix;
 	ix = _ix;
-	wf_move_si(wf,to.x - from.x, to.y - from.y);
+	wf_move_si(gf, wf, to.x - from.x, to.y - from.y);
 	wf->flags |= WFF_PLOT_DIRTY;
 	return 0;
 }
