@@ -144,6 +144,8 @@ _ch_lock(LOCK_D *lock_bit,char * file,int line)
 		sleep_task((int)lock_bit,gbview_flame_lock);
 		lock_task(gbview_flame_lock);
 	}
+	if ( file == 0 )
+		er_panic("_ch_lock");
 	lock_bit->file = file;
 	lock_bit->line = line;
 	lock_bit->tid = _get_tid();
@@ -1174,7 +1176,7 @@ unsigned int now_t;
 		return 1;
 	c = 0;
 	now_t = get_xltime();
-	calc_pitch(gf,0); 
+	_calc_pitch(gf,0); 
 	for ( wf = gf->flame ; wf ; wf = wf->next ) {
 		if ( wf == gf->flame_base )
 			continue;
@@ -1268,7 +1270,7 @@ printf("*********SET  %f %f %f %f %f\n",reso,center.x,center.y,gf->flame_base_ro
 	gf->flame_base_rotate = rotate;
 	gf->flame_base_resolution = reso;
 	c->in_base_time = now_t;
-	calc_pitch(gf,1);
+	_calc_pitch(gf,1);
 	free_mh(base);
 	return 1;
 }
@@ -1632,14 +1634,10 @@ int ret;
 		ret = 0;
 		break;
 	case MHT_LINEAR:
-set_t_msg(250);
 		ret = wf_move_xy(gf,from,to);
-set_t_msg(251);
 		break;
 	case MHT_PP:
-set_t_msg(252);
 		ret = wf_move_globe(gf,from,to);
-set_t_msg(253);
 		break;
 	default:
 		er_panic("wf_move");
@@ -1740,7 +1738,7 @@ int ret;
 	}
 
 	wf_im_zoom_proc(gf->redraw_plane,ow,oh,index_x,index_y);
-	calc_pitch(gf,0);
+	_calc_pitch(gf,0);
 
 	len = gf->win_width*gf->win_height;
 	for ( i = 0 ; i < len ; i ++ )
@@ -1796,7 +1794,7 @@ int ret;
 		wf->flags |= WFF_RESIZE;
 		_wakeup_wf(gf,wf);
 	}
-	calc_pitch(gf,1);
+	_calc_pitch(gf,1);
 	_change_redraw(gf);
 
 	new_tick(_wf_set_redraw,0,(int)gf);
@@ -2415,7 +2413,7 @@ set_t_msg(37);
 				p_sub(ptr_list[1],ptr_list[0]));
 		}
 	}
-	calc_pitch(gf,1);
+	_calc_pitch(gf,1);
 	_all_dirty_out(gf);
 	assert_ls(gf,LSF_ZOOM);
 	wf_unlock(gf);
@@ -2871,9 +2869,9 @@ WIN_FLAME * wf;
 		_wakeup_wf(gf,wf);
 	}
 	d_f_ree(index);
-	calc_pitch(gf,0);
+	_calc_pitch(gf,0);
 	gf->flame_base_rotate -= get_radian(gf,from,to);
-	calc_pitch(gf,1);
+	_calc_pitch(gf,1);
 
 	ret = _get_env_seq(gf);
 	wf_unlock(gf);
@@ -3033,6 +3031,7 @@ int ret;
 		return 0;
 	wf_lock(gf);
 set_t_msg(49);
+	ZONBIE_CHECK(gf,wf_unlock,0)
 	rlist_len = 0;
 	for ( wf = gf->flame ; wf ; wf = wf->next ) {
 		if ( wf->draw->c.button_action )
@@ -3254,6 +3253,7 @@ int ret;
 int change,st_change;
 int shift;
 	wf_lock(gf);
+	ZONBIE_CHECK(gf,wf_unlock,0)
 set_t_msg(51);
 	change = 0;
 	st_change = 0;
@@ -3300,6 +3300,7 @@ INFO_LIST * info;
 int seq;
 
 	wf_lock(gf);
+	ZONBIE_CHECK_VOID(gf,wf_unlock)
 set_t_msg(52);
 	info = gf->click_op_list;
 	gf->click_op_list = 0;
@@ -3333,7 +3334,10 @@ int i;
 
 	if ( lst )
 		il2 = il = lst;
-	else	il2 = il = sts.infolist;
+	else {
+		il2 = il = sts.infolist;
+		sts.infolist = 0;
+	}
 
 	for ( il = il2 ; il ; il = il->next ) {
 		if ( wf_button_action(gf,il->obj,"click") )
