@@ -180,8 +180,10 @@ if ( localhost_check_str(start,"routing_optimize_el") < 0 ) {
 	if ( mpi == 0 )
 		return;
 	a = get_mpi_around(mpi);
-	if ( a == 0 )
+	if ( a == 0 ) {
+		flush_mpi(mpi);
 		return;
+	}
 	flush_mpi(mpi);
 	for ( i = n->mp_ptr-1 ; i > pos+1 ; i -- ) {
 		result = cmp_around(n->mp_tbl[i].crd,a);
