@@ -21,6 +21,14 @@
 #define ___MEMORY_DEBUG_H___
 
 
+typedef struct mem_free_info {
+	struct mem_free_info *	next;
+	struct mem_free_info *	time_next;
+	unsigned int		ptr;
+	char *			file;
+	int			line;
+} MEM_FREE_INFO;
+
 typedef struct mem_list {
 	struct mem_list *	next;
 	char *			file;
