@@ -61,6 +61,8 @@ typedef struct radar_lump {
 	L_CHAR *		lumpcrd_path;
 	L_CHAR *		db_path;
 	GB_RECT			sphere;
+	L_CHAR *		unit;
+	L_CHAR *		reso_unit;
 	REAL1			reso_min;
 	REAL1			reso_max;
 	LUMP_CRD_NODE *		crd;
