@@ -34,7 +34,7 @@ char * _f;
 		p = 0;
 		goto end;
 	}
-	p = d_alloc(sizeof(*p),2);
+	p = d_alloc(sizeof(*p));
 	p->fid = fid;
 	p->flags = flags;
 	u_lseek(fid,0,SEEK_SET);
