@@ -64,7 +64,7 @@ put_lstr(S_PRINTF_STREAM *s, L_CHAR *lstr){
 	if(memsize_changed){
 		if(s->mem == 0)
 			s->mem = (L_CHAR*)d_alloc(
-				s->mem_size*sizeof(L_CHAR),12);
+				s->mem_size*sizeof(L_CHAR));
 		else
 			s->mem = (L_CHAR*)d_re_alloc(
 				s->mem, s->mem_size*sizeof(L_CHAR));
@@ -91,7 +91,7 @@ _s_printf(STREAM *s, char * fmt, va_list p){
 	memset(&out, 0, sizeof(S_PRINTF_STREAM));
 
 
-	temp = d_alloc(strlen(fmt)+1,33);
+	temp = d_alloc(strlen(fmt)+1);
 	
 	/* begin parse */
 	in_begin = fmt;
@@ -230,7 +230,7 @@ _s_printf(STREAM *s, char * fmt, va_list p){
 		work = s->h.cm_work;
 		
 		len = 4*out.len;
-		ret = d_alloc(len+1, 354);
+		ret = d_alloc(len+1);
 		ptr = 0;
 		
 		for( ; *str; str++){
