@@ -28,8 +28,13 @@ void
 s_set_cr(STREAM * s,int cnt)
 {
 	lock_task(stream_lock);
+	if ( s == 0 )
+		goto end;
+	if ( s->h.tbl == 0 )
+		goto end;
 	s->h.cr_mode = CRM_COUNT;
 	s->h.cr_cnt = cnt;
+end:
 	unlock_task(stream_lock,"s_set_cr");
 }
 
