@@ -25,8 +25,7 @@
 
 int
 get_url2(URL *	ret,
-	L_CHAR * url,
-	int no)
+	L_CHAR * url)
 {
 L_CHAR * buf;
 L_CHAR * div;
@@ -38,7 +37,7 @@ int er;
 
 	er = 0;
 	zero_url(ret);
-	buf = ll_copy_str(url,no);
+	buf = ll_copy_str(url);
 	len = l_strlen(url);
 	div = nl_copy_str(std_cm,"://");
 	for ( p = 0 ; p < len-3 ; p ++ )
@@ -54,7 +53,7 @@ int er;
 	goto dir_res;
 match:
 	buf[p] = 0;
-	ret->proto = ll_copy_str(buf,no);
+	ret->proto = ll_copy_str(buf);
 	p += 3;
 	host = &buf[p];
 	for ( ; buf[p] && buf[p] != ':' && buf[p] != '/' ; p ++ );
@@ -78,7 +77,7 @@ match:
 		}
 	}
 	buf[p] = 0;
-	ret->server = ll_copy_str(host,no);
+	ret->server = ll_copy_str(host);
 	switch ( ch ) {
 	case 0:
 		ret->port = 0;
@@ -116,17 +115,17 @@ dir_res:
 		if ( dir[p] == '/' )
 			goto res;
 	ret->db = 0;
-	ret->resource = ll_copy_str(dir,no);
+	ret->resource = ll_copy_str(dir);
 	goto end;
 res:
 	if ( len == p ) {
 		ret->resource = 0;
-		ret->db = ll_copy_str(dir,no);
+		ret->db = ll_copy_str(dir);
 	}
 	else {
-		ret->resource = ll_copy_str(&dir[p+1],no);
+		ret->resource = ll_copy_str(&dir[p+1]);
 		dir[p+1] = 0;
-		ret->db = ll_copy_str(dir,no);
+		ret->db = ll_copy_str(dir);
 	}
 end:
 	d_f_ree(buf);
