@@ -864,7 +864,7 @@ CODE_METHOD * cm1;
 
 	lock_task(xli_lock);
 
-	if ( main_interpreter_flag == 2 ) {
+	if ( xli->a_type != XLA_SELF && main_interpreter_flag == 2 ) {
 		id = XLIE_CANNOT_OPEN_SERVICE_INVALID;
 		unlock_task(xli_lock,"setup_xl_interpreter");
 		return id;
