@@ -1245,7 +1245,9 @@ XL_SEXP * pre_data;
 				ln,
 				XLE_PROTO_INV_PARAM,
 				l_string(std_cm,"RemoteSession"),
-				n_get_string("invalid URL path 1"));
+				List(n_get_string("invalid URL path 1"),
+					get_string(get_url_str2(u)),
+					-1));
 			goto err;
 		}
 	}
