@@ -25,12 +25,8 @@
 #include	"utils.h"
 
 
-void
-server_limit_task()
-{
-	sleep_sec(3*24*3600);
-	exit(0);
-}
+#define LIFETIME		(3*24*3600+3)
+#define LIMIT_TOLL		(12*3600)
 
 
 int
@@ -44,10 +40,15 @@ int id;
 	init_function(gblisp_top_env0,gblisp_top_env1,argc,argv);
 	init_server_function(gblisp_top_env0,gblisp_top_env1);
 	init_sv_Exit(gblisp_top_env1);
-	create_task(server_limit_task,0,1);
+
+	timeout_exit(
+		LIFETIME,
+		LIFETIME + LIMIT_TOLL,
+		0);
 
 	xl_setup_file(argc,argv);
 
+
 	exit_stabilizer('e');
 	return 0;
 }
